#!/bin/sh
#set -x

############################################################################
#                                                                          # 
# tru64_local_install.sh                                                   #
# Local Install for tru64 Operating System                                 #
#                                                                          #
# Usage : tru64_local_install.sh                                           #
#                                                                          #
# Version : 1.0                                                            #
# Created : Friday, August 12th, 2005                                      #
# Author  : KK Senthil Kumar                                               # 
# @(#) (c) Copyright 2005 Hewlett-Packard Development Company, L.P         # 
# Decription : This script will install the AppStorM Tru64 CIM Extensions  #
#              on tru64 operating system and starts up the required demons #
#                                                                          #
############################################################################

checkInstall()
{ 
  echo
  echo "Checking for any already Installed HP APPQCIME Package"
  echo
  
  SHELL_LIB=${SHELL_LIB:-/usr/share/lib/shell}
  . $SHELL_LIB/libswdb
  . $SHELL_LIB/libscp

  STL_ScpInit
  SWDB_IsInstalled $1
  if [ $? -eq 0 ]
  then
       APPQCIME_INSTALLED="true"
  else
       APPQCIME_INSTALLED="false"
  fi 
}

set_file_ownership()
{
(
  cd instctrl
  # Replace the UID and GID fields in the inventory file - these are the
  # 4th and 5th fields in the inventory file for that subset.

  for inv in `ls *.inv`
  do
    awk -v U_ID=$1 -v G_ID=$2 '{ print $1"\t"$2"\t"$3"\t"U_ID"\t"G_ID"\t"$6"\t"$7"\t"$8"\t"$9"\t"$10"\t"$11"\t"$12 }' \
        $inv > tmp.inv
    mv tmp.inv $inv
  done
  cd ..
)
} 
   
localInstall()
{
  echo "Start Install of AppStorM Tru64 CIM Extensions"
  echo
 
  TIMESTAMP=`date +"%x%r" | sed "s/[ :\/]//g"`
  TEMP_DIR=/tmp/$TIMESTAMP
  savedir=`pwd`

  if [ -f ./$1.tar ]
  then
      mkdir -p $TEMP_DIR
      cp ./$1.tar $TEMP_DIR
      if [ $? -ne 0 ] 
      then 
          echo "Installation of AppStorM Tru64 CIM Extensions failed"
          echo "Please check the disk space requirements on the host."
          echo
          rm -rf $TEMP_DIR
          exit 1
      fi
      cd $TEMP_DIR  
      
      /sbin/tar xf $1.tar . > /dev/null 2>&1
      if [ $? -ne 0 ] 
      then 
          echo "Installation of AppStorM Tru64 CIM Extensions failed"
          echo "Please check the disk space requirements on the host."
          echo 
          rm -rf $TEMP_DIR 
          exit 1
      fi
      
      if [ -f $INSTALL_LOG ]
      then
          rm -f $INSTALL_LOG > /dev/null 2>&1
      fi
      
      set_file_ownership $USR_ID $GRP_ID
      
      # Install the HP APPQCIME Package
      /usr/sbin/setld -l . $1 >> ${INSTALL_LOG} 2>&1
      if [ $? -eq 0 ]
      then
              INSTALL_STATE="GOOD"
      fi
      
      rm -rf $TEMP_DIR
      cd $savedir
  else
      echo "Installation of AppStorM Tru64 CIM Extensions failed"
      echo "Couldn't find an appropriate installation package"
      echo
      exit 1
  fi
 
  if [ "$INSTALL_STATE" = "GOOD" ]
  then
      echo "Installation of AppStorM Tru64 CIM Extensions was successful"
      echo
  else
      echo "Installation of AppStorM Tru64 CIM Extensions failed"
      echo "Please check $INSTALL_LOG for details."
      echo
      exit 1
  fi
}

startCIM_local()
{
  savedir=`pwd`
  cd $CIM_INSTALL_TOOLS_DIR
  if [ $? -eq 0 ]
  then
      if [ -f start ]
      then
          echo "Starting AppStorM Tru64 CIM Extensions on working node"
          echo
         
          # Start the HP APPQCIME Process 
          ./start >/dev/null 2>/dev/null &
          sleep 3 
      fi
  fi
  cd $savedir
}
startCIM_cluster()
{
  if [ "$1" = "" ]
  then 
     return 1
  fi 
  
  CL_MEMBER_NAME=$1
  RSH="/usr/bin/rsh $CL_MEMBER_NAME"

  echo "Starting APPStorM Tru64 CIM Extensions on cluster node $1"
  echo
 
  # Start the HP APPQCIME Service on Cluster Nodes
  $RSH ./$CIM_INSTALL_TOOLS_DIR/start >/dev/null 2>/dev/null & 
  sleep 3 
} 

clusterTest()
{
  if [ "$CURNODEONLY" = "TRUE" ]
  then
      startCIM_local 
      return
  fi

  /usr/sbin/clu_get_info -q > /dev/null 2>&1 
  if [ $? -eq 0 ]
  then
      CL_MEMBERS=`/usr/sbin/clu_get_info -raw | /sbin/grep "^M:" | /usr/bin/cut -f2 -d:`
      NODE_ID=`/usr/sbin/clu_get_info -raw | /sbin/grep "^C:" | /usr/bin/cut -f4 -d:` 
      for CL_MEMBER in `echo $CL_MEMBERS`
      do
        MEMBER_NAME=`/usr/sbin/clu_get_info -raw | /sbin/grep "^M:$CL_MEMBER:" | /usr/bin/cut -f4 -d:`
        MEMBER_STATE=`/usr/sbin/clu_get_info -raw | /sbin/grep "^M:$CL_MEMBER:" | /usr/bin/cut -f6 -d:`
        if [ "$MEMBER_STATE" = "UP" ]
        then
           if [ "$NODE_ID" = "$CL_MEMBER" ]
           then 
               startCIM_local
           else
               startCIM_cluster $MEMBER_NAME 
           fi
        else
           echo "The state of the member $MEMBER_NAME is $MEMBER_STATE so not able to start the service"
           echo
        fi 
      done
  else
      startCIM_local 
  fi
}
################################ MAIN SCRIPT PORTION ####################################

PATH=/usr/sbin:/usr/bin:/bin:/sbin:$PATH
INSTALL_LOG=/tmp/tru64_local_install.log
CIM_INSTALL_DIR=/opt/APPQcime
CIM_INSTALL_TOOLS_DIR=/opt/APPQcime/tools
PKG_NAME=APPQCIME
CURNODEFLAG=NO$1
CURNODEONLY="FALSE"

#You must be root
id | grep uid=0\( 1>/dev/null 2>&1
if [ $? -ne 0 ]
	then echo "You must be root to install the CIM Extension"
    exit 1
fi

cd `dirname $0`

if [ $CURNODEFLAG != "NO" ]
then
  if [ "$1" = "-CURNODE" -o "$1" = "-curnode" ]
  then
    echo
    echo "Agent will be activated on current node only"
    CURNODEONLY="TRUE"
  fi
fi

OS_TYPE=`uname`
if [ "$OS_TYPE" = "OSF1" ]
then
    checkInstall $PKG_NAME
    if [ "$APPQCIME_INSTALLED" = "true" ]
    then
        echo "An HP APPQCIME agent is already installed"
        echo 
        exit 1
    elif [ "$APPQCIME_INSTALLED" = "false" ]
    then
    	# Find out the uid and gid for bin:bin
    	USR_ID=`/sbin/grep "^bin" /etc/passwd | cut -f3 -d:`
    	GRP_ID=`/sbin/grep "^bin" /etc/group | cut -f3 -d:`
  
    	localInstall $PKG_NAME

        clusterTest 

        #if [ -f $CIM_INSTALL_TOOLS_DIR/postinstall_appqcime ]
        #then
            #$CIM_INSTALL_TOOLS_DIR/postinstall_appqcime >/dev/null 2>/dev/null & 
        #fi
    fi
fi
echo "Install log can be found at ${INSTALL_LOG}"
