#!/bin/sh
#set -x

############################################################################
#                                                                          # 
# tru64_local_uninstall.sh                                                 #
# Local Install for tru64 Operating System                                 #
#                                                                          #
# Usage : tru64_local_uninstall.sh                                         #
#                                                                          #
# Version : 1.0                                                            #
# Created : Friday, August 12th, 2005                                      #
# Author  : KK Senthil Kumar                                               #
# @(#) (c) Copyright 2005 Hewlett-Packard Development Company, L.P         #
# Decription : This script will uninstall the AppStorM Tru64 CIM Extensions#
#              on tru64 operating system                                   #
#                                                                          #
############################################################################

checkInstall()
{
  echo
  echo "Checking for any Installed HP APPQCIME Package"
  echo

  SHELL_LIB=${SHELL_LIB:-/usr/share/lib/shell}
  . $SHELL_LIB/libswdb
  . $SHELL_LIB/libscp

  STL_ScpInit
  SWDB_IsInstalled $1
  if [ $? -eq 0 ]
  then
       APPQCIME_INSTALLED="true"
  else
       APPQCIME_INSTALLED="false"
  fi
}

localUninstall()
{
  echo "Start to Uninstall AppStorM Tru64 CIM Extensions"
  echo

  if [ -f $UNINSTALL_LOG ]
  then 
      rm -f $UNINSTALL_LOG > /dev/null 2>&1
  fi 

  #Uninstall the HP APPQCIME Package 
  /usr/sbin/setld -d $1 >> ${UNINSTALL_LOG} 2>&1
  if [ $? -eq 0 ] 
  then 
      UNINSTALL_STATE="GOOD"
  fi
 
  if [ "$UNINSTALL_STATE" = "GOOD" ]
  then
      echo "Uninstallation of AppStorM Tru64 CIM Extensions was successful"
      echo
      echo "Uninstall log can be found at ${UNINSTALL_LOG}"
      echo
  else
      echo "Uninstallation of AppStorM Tru64 CIM Extensions failed"
      echo "Please check ${UNINSTALL_LOG} for details."
      exit 1
  fi
}

stopCIM_local()
{
  savedir=`pwd` 
  cd $CIM_INSTALL_TOOLS_DIR
  if [ $? -eq 0 ]
  then
      if [ -f stop ]
      then 
          echo "Stopping AppStorM Tru64 CIM Extensions on the working node"
          echo
 
          # If the APPQCIME is UP, stop the process   
          ./stop >/dev/null 2>/dev/null &
          sleep 3
      fi
  fi
  cd $savedir
}

stopCIM_cluster()
{
  if [ "$1" = "" ]
  then
     return 1
  fi

  RSH="/usr/bin/rsh $1"

  echo "Stopping APPStorM Tru64 CIM Extensions on node $1"
  echo

  # Stop the HP APPQCIME Service on Cluster Nodes
  $RSH ./$CIM_INSTALL_TOOLS_DIR/stop >/dev/null 2>/dev/null &
  sleep 3
}

clusterTest()
{
  /usr/sbin/clu_get_info -q > /dev/null 2>&1
  if [ $? -eq 0 ]
  then
      echo " The agent will be uninstalled from all nodes of this cluster"
      echo
      CL_MEMBERS=`/usr/sbin/clu_get_info -raw | /sbin/grep "^M:" | /usr/bin/cut -f2 -d:`
      NODE_ID=`/usr/sbin/clu_get_info -raw | /sbin/grep "^C:" | /usr/bin/cut -f4 -d:`
      for CL_MEMBER in `echo $CL_MEMBERS`
      do
        CL_MEMBER_NAME=`/usr/sbin/clu_get_info -raw | /sbin/grep "^M:$CL_MEMBER:" | /usr/bin/cut -f4 -d:`
        CL_MEMBER_STATE=`/usr/sbin/clu_get_info -raw | /sbin/grep "^M:$CL_MEMBER:" | /usr/bin/cut -f6 -d:`
        if [ "$CL_MEMBER_STATE" = "UP" ]
        then
           if [ "$NODE_ID" = "$CL_MEMBER" ]
           then
               stopCIM_local
           else
               stopCIM_cluster $CL_MEMBER_NAME
           fi
        else
           echo "The state of the member $CL_MEMBER_NAME is $CL_MEMBER_STATE so not able to stop the service"
           echo
        fi
      done
  else
      stopCIM_local
  fi
}

deleteRc()
{
  rm -f /sbin/init.d/appqcime > /dev/null 2>&1
  rm -f /sbin/rc0.d/K99appqcime > /dev/null 2>&1
  rm -f /sbin/rc2.d/K99appqcime > /dev/null 2>&1
  rm -f /sbin/rc3.d/S99appqcime > /dev/null 2>&1
}

################################ MAIN SCRIPT PORTION ####################################

PATH=/usr/sbin:/usr/bin:/bin:/sbin:$PATH
UNINSTALL_LOG=/tmp/tru64_local_uninstall.log
CIM_INSTALL_DIR=/opt/APPQcime
CIM_INSTALL_TOOLS_DIR=/opt/APPQcime/tools
PKG_NAME=APPQCIME

cd `dirname $0`

OS_TYPE=`uname`
if [ "$OS_TYPE" = "OSF1" ]
then
    #You must be root
    id | grep uid=0\( 1>/dev/null 2>&1
    if [ $? -ne 0 ]
	then echo "You must be root to uninstall the CIM Extension"
        exit 1
    fi
    checkInstall $PKG_NAME
    if [ "$APPQCIME_INSTALLED" = "true" ]
    then
        clusterTest
        localUninstall $PKG_NAME
        deleteRc 
	echo "The uninstallation was successful.Please delete /opt/APPQcime and /cluster/members/{memb}/opt/APPQcime directories manually " >> $UNINSTALL_LOG
        exit 1
    elif [ "$APPQCIME_INSTALLED" = "false" ]
    then 
        echo "The host has no installed package of HP APPQCIME to be removed."
        echo
    fi
fi  	 
       	 
